@@ -38,12 +38,7 @@ extern "C"
 {
 #endif /* __cplusplus */
 
-/*
-	AFvirtualfile is the preferred type to use; AF_VirtualFile will go
-	away.
-*/
-typedef struct _AF_VirtualFile AFvirtualfile;
-typedef struct _AF_VirtualFile AF_VirtualFile;
+typedef struct _AFvirtualfile AFvirtualfile;
 
 typedef struct _AFfilesetup *AFfilesetup;
 typedef struct _AFfilehandle *AFfilehandle;
@@ -85,7 +80,9 @@ enum
 	AF_FILE_AIFFC = 1,
 	AF_FILE_AIFF = 2,
 	AF_FILE_NEXTSND = 3,
-	AF_FILE_WAVE = 4
+	AF_FILE_WAVE = 4,
+	AF_FILE_BICSF = 5,
+	AF_FILE_IRCAM = AF_FILE_BICSF
 };
 
 enum
@@ -169,8 +166,11 @@ enum
 	AF_COMPRESSION_G726 = 517,
 	AF_COMPRESSION_G728 = 518,
 	AF_COMPRESSION_DVI_AUDIO = 519,
+	AF_COMPRESSION_IMA = AF_COMPRESSION_DVI_AUDIO,
 	AF_COMPRESSION_GSM = 520,
-	AF_COMPRESSION_FS1016 = 521
+	AF_COMPRESSION_FS1016 = 521,
+	AF_COMPRESSION_DV = 522,
+	AF_COMPRESSION_MS_ADPCM = 523
 };
 
 /* tokens for afQuery() -- see the man page for instructions */
@@ -400,7 +400,8 @@ int afIdentifyNamedFD (int, const char *filename, int *implemented);
 
 AFfilehandle afOpenFile (const char *filename, const char *mode,
 	AFfilesetup setup);
-AFfilehandle afOpenVirtualFile(AF_VirtualFile *vfile, const char *mode, AFfilesetup setup);
+AFfilehandle afOpenVirtualFile (AFvirtualfile *vfile, const char *mode,
+	AFfilesetup setup);
 AFfilehandle afOpenFD (int fd, const char *mode, AFfilesetup setup);
 AFfilehandle afOpenNamedFD (int fd, const char *mode, AFfilesetup setup,
 	const char *filename);
@@ -419,7 +420,7 @@ int afGetTrackIDs (AFfilehandle, int *trackids);
 
 /* track data: reading, writng, seeking, sizing frames */
 int afReadFrames (AFfilehandle, int track, void *buffer, int frameCount);
-int afWriteFrames (AFfilehandle, int track, void *buffer, int frameCount);
+int afWriteFrames (AFfilehandle, int track, const void *buffer, int frameCount);
 AFframecount afSeekFrame (AFfilehandle, int track, AFframecount frameoffset);
 AFfileoffset afTellFrame (AFfilehandle, int track);
 AFfileoffset afGetTrackBytes (AFfilehandle, int track);
