@@ -18,10 +18,18 @@
 	Boston, MA  02111-1307  USA.
 */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <stdlib.h>
 #include <assert.h>
 #include <string.h>
 
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
 #include <audiofile.h>
 
 #include "afinternal.h"
@@ -29,6 +37,10 @@
 #include "util.h"
 #include "modules.h"
 
+#ifndef _MSC_VER
+#define SETBINARYMODE(x)
+#endif
+
 extern _Unit _af_units[];
 
 static void freeFileHandle (AFfilehandle filehandle);
@@ -83,6 +95,8 @@ int afIdentifyFD (int fd)
 		return AF_FILE_UNKNOWN;
 	}
 
+	SETBINARYMODE(fp);
+
 	vf = af_virtual_file_new_for_file(fp);
 	if (vf == NULL)
 	{
@@ -117,6 +131,8 @@ int afIdentifyNamedFD (int fd, const char *filename, int *implemented)
 		return AF_FILE_UNKNOWN;
 	}
 
+	SETBINARYMODE(fp);
+
 	vf = af_virtual_file_new_for_file(fp);
 	if (vf == NULL)
 	{
@@ -160,6 +176,8 @@ AFfilehandle afOpenFD (int fd, const char *mode, AFfilesetup setup)
 		return AF_NULL_FILEHANDLE;
 	}
 
+	SETBINARYMODE(fp);
+
 	vf = af_virtual_file_new_for_file(fp);
 
 	if (_afOpenFile(access, vf, NULL, &filehandle, setup) != AF_SUCCEED)
@@ -198,6 +216,8 @@ AFfilehandle afOpenNamedFD (int fd, const char *mode, AFfilesetup setup,
 		return AF_NULL_FILEHANDLE;
 	}
 
+	SETBINARYMODE(fp);
+
 	vf = af_virtual_file_new_for_file(fp);
 
 	if (_afOpenFile(access, vf, filename, &filehandle, setup) != AF_SUCCEED)
@@ -235,6 +255,8 @@ AFfilehandle afOpenFile (const char *filename, const char *mode, AFfilesetup set
 		return AF_NULL_FILEHANDLE;
 	}
 
+	SETBINARYMODE(fp);
+
 	vf = af_virtual_file_new_for_file(fp);
 
 	if (_afOpenFile(access, vf, filename, &filehandle, setup) != AF_SUCCEED)
@@ -484,6 +506,21 @@ static void freeFileHandle (AFfilehandle filehandle)
 		int	i;
 		for (i=0; i<filehandle->trackCount; i++)
 		{
+			/* Free the compression parameters. */
+			if (filehandle->tracks[i].f.compressionParams)
+			{
+				AUpvfree(filehandle->tracks[i].f.compressionParams);
+				filehandle->tracks[i].f.compressionParams = AU_NULL_PVLIST;
+			}
+
+			if (filehandle->tracks[i].v.compressionParams)
+			{
+				AUpvfree(filehandle->tracks[i].v.compressionParams);
+				filehandle->tracks[i].v.compressionParams = AU_NULL_PVLIST;
+			}
+
+			/* Free the track's modules. */
+
 			_AFfreemodules(&filehandle->tracks[i]);
 
 			if (filehandle->tracks[i].channelMatrix)
