@@ -1,7 +1,8 @@
 /*
 	Audio File Library
 
-	Copyright 1999, Michael Pruett <michael@68k.org>
+	Copyright (C) 2000, Michael Pruett <michael@68k.org>
+	Copyright (C) 2001, Silicon Graphics, Inc.
 
 	This program is free software; you can redistribute it and/or
 	modify it under the terms of the GNU General Public License as
@@ -48,7 +49,12 @@
 #include <stdio.h>
 #include <unistd.h>
 
-#define TEST_FILE "/tmp/fuck.au"
+#define TEST_FILE "/tmp/test.ulaw"
+
+#define FRAME_COUNT 16
+#define SAMPLE_COUNT FRAME_COUNT
+
+void testulaw (int fileFormat);
 
 void cleanup (void)
 {
@@ -68,18 +74,33 @@ void ensure (int condition, const char *message)
 }
 
 int main (int argc, char **argv)
+{
+	printf("writeulaw: testing NeXT .snd.\n");
+	testulaw(AF_FILE_NEXTSND);
+	printf("writeulaw: testing AIFF-C.\n");
+	testulaw(AF_FILE_AIFFC);
+	printf("writeulaw: testing WAVE.\n");
+	testulaw(AF_FILE_WAVE);
+
+	printf("writeulaw test passed.\n");
+
+	exit(0);
+}
+
+void testulaw (int fileFormat)
 {
 	AFfilehandle	file;
-	AFfilesetup		setup;
-	u_int16_t		frames[] = {8, 16, 80, 120, 180, 780, 924, 988,
-						1116, 1436, 1884, 8828, 9852, 15996, 19836, 32124};
-	u_int16_t		readframes[16];
-	int				i;
+	AFfilesetup	setup;
+	u_int16_t	samples[] = {8, 16, 80, 120, 180, 780, 924, 988,
+			1116, 1436, 1884, 8828, 9852, 15996, 19836, 32124};
+	u_int16_t	readsamples[SAMPLE_COUNT];
+	AFframecount	framesWritten, framesRead;
+	int		i;
 
 	setup = afNewFileSetup();
 
 	afInitCompression(setup, AF_DEFAULT_TRACK, AF_COMPRESSION_G711_ULAW);
-	afInitFileFormat(setup, AF_FILE_NEXTSND);
+	afInitFileFormat(setup, fileFormat);
 	afInitChannels(setup, AF_DEFAULT_TRACK, 1);
 
 	file = afOpenFile(TEST_FILE, "w", setup);
@@ -91,7 +112,10 @@ int main (int argc, char **argv)
 
 	ensure(file != AF_NULL_FILEHANDLE, "unable to open file for writing");
 
-	ensure(afWriteFrames(file, AF_DEFAULT_TRACK, frames, 16) == 16,
+	framesWritten = afWriteFrames(file, AF_DEFAULT_TRACK, samples,
+		FRAME_COUNT);
+
+	ensure(framesWritten == FRAME_COUNT,
 		"number of frames requested does not match number of frames written");
 	afCloseFile(file);
 
@@ -99,35 +123,37 @@ int main (int argc, char **argv)
 	file = afOpenFile(TEST_FILE, "r", NULL);
 	ensure(file != AF_NULL_FILEHANDLE, "unable to open file for reading");
 
-	ensure(afGetFileFormat(file, NULL) == AF_FILE_NEXTSND,
-		"test file not created as NeXT/Sun .snd/.au");
+	ensure(afGetFileFormat(file, NULL) == fileFormat,
+		"test file format incorrect");
 
 	ensure(afGetCompression(file, AF_DEFAULT_TRACK) ==
 		AF_COMPRESSION_G711_ULAW,
 		"test file not opened with G.711 u-law compression");
 
-	ensure(afReadFrames(file, AF_DEFAULT_TRACK, readframes, 16) == 16,
+	framesRead = afReadFrames(file, AF_DEFAULT_TRACK, readsamples,
+		FRAME_COUNT);
+
+	ensure(framesRead == FRAME_COUNT,
 		"number of frames read does not match number of frames requested");
 
 #ifdef DEBUG
-	for (i=0; i<16; i++)
-		printf("readframes[%d]: %d\n", i, readframes[i]);
-	for (i=0; i<16; i++)
-		printf("frames[%d]: %d\n", i, frames[i]);
+	for (i=0; i<SAMPLE_COUNT; i++)
+		printf("readsamples[%d]: %d\n", i, readsamples[i]);
+	for (i=0; i<SAMPLE_COUNT; i++)
+		printf("samples[%d]: %d\n", i, samples[i]);
 #endif
 
-	for (i=0; i<16; i++)
+	for (i=0; i<SAMPLE_COUNT; i++)
 	{
-		ensure(frames[i] == readframes[i],
+		ensure(samples[i] == readsamples[i],
 			"data written does not match data read");
 	}
 
-	printf("track bytes: %d\n", afGetTrackBytes(file, AF_DEFAULT_TRACK));
-
-	ensure(afGetTrackBytes(file, AF_DEFAULT_TRACK) == 16,
+	/* G.711 compression uses one byte per sample. */
+	ensure(afGetTrackBytes(file, AF_DEFAULT_TRACK) == SAMPLE_COUNT,
 		"track byte count is incorrect");
 
-	ensure(afGetFrameCount(file, AF_DEFAULT_TRACK) == 16,
+	ensure(afGetFrameCount(file, AF_DEFAULT_TRACK) == FRAME_COUNT,
 		"frame count is incorrect");
 
 	ensure(afGetChannels(file, AF_DEFAULT_TRACK) == 1,
@@ -136,8 +162,4 @@ int main (int argc, char **argv)
 	ensure(afCloseFile(file) == 0, "error closing file");
 
 	cleanup();
-
-	printf("writeulaw test passed.\n");
-
-	exit(0);
 }
